from django.apps import AppConfig


class DFSAASBlogAppConfig(AppConfig):
    name = 'dfsaas_blog'
    verbose_name = "Blog"
    label = 'dfsaas_blog'
